@@ -4,7 +4,7 @@ import numpy as np
 from PPVD.validation import validate_evenly_divisible, validate_matrix, validate_numpy_type, validate_tensor
 
 
-def generate_raster(event_frames: List[List[int]], total_frames: Optional[int] = None):
+def generate_raster(event_frames: List[List[int]], total_frames: Optional[int] = None) -> np.ndarray:
     """
     Generate raster from lists of frames containing an event (e.g., spikes)
 
@@ -13,10 +13,10 @@ def generate_raster(event_frames: List[List[int]], total_frames: Optional[int] =
     :param total_frames: total number of frames
     :type total_frames: Optional[int] = None
     :return: event matrix of neurons x total frames
-    :rtype: np.ndarray
+    :rtype: numpy.ndarray
     """
-    # if total frames not provided we estimate by finding the very last event
-    if not total_frames:
+
+    if not total_frames:  # if total frames not provided we estimate by finding the very last event
         total_frames = np.max([event for events in event_frames for event in events])+1  # + 1 to account for 0-index
     _neurons = len(event_frames)
     event_matrix = np.full((_neurons, total_frames), 0, dtype=np.int32)
@@ -33,11 +33,13 @@ def generate_raster(event_frames: List[List[int]], total_frames: Optional[int] =
 def generate_tensor(traces_as_matrix: np.ndarray, chunk_size: int) -> np.ndarray:
     """
     Generates a tensor given chunk / trial indices
+
     :param traces_as_matrix: traces in matrix form (neurons x frames)
-    :type traces_as_matrix: np.ndarray
+    :type traces_as_matrix: numpy.ndarray
     :param chunk_size: size of each chunk
     :type chunk_size: int
-    :return:
+    :return: traces_as_tensor
+    :rtype: numpy.ndarray
     """
     return np.stack(np.hsplit(traces_as_matrix, traces_as_matrix.shape[1]//chunk_size), axis=0)
 
@@ -49,9 +51,9 @@ def merge_tensor(traces_as_tensor: np.ndarray) -> np.ndarray:
 
 
     :param traces_as_tensor: chunk (trial, tiff, etc) x neurons x frames
-    :type traces_as_tensor: np.ndarray
+    :type traces_as_tensor: numpy.ndarray
     :return: traces in matrix form
-    :rtype: np.ndarray
+    :rtype: numpy.ndarray
     """
     return np.hstack(traces_as_tensor)
 
@@ -64,12 +66,12 @@ def merge_factorized_matrices(factorized_traces: np.ndarray, component: int = 0)
 
 
     :param factorized_traces: neurons x chunks (trial, tiff, etc) containing the neuron's trace factorized
-    into several components
-    :type factorized_traces: np.ndarray
+        into several components
+    :type factorized_traces: numpy.ndarray
     :param component: specific component to extract
     :type component: int
     :return: traces of specific component in matrix form
-    :rtype: np.ndarray
+    :rtype: numpy.ndarray
     """
     _neurons, _trials = factorized_traces.shape
     _frames = np.concatenate(factorized_traces[0], axis=1)[0, :].shape[0]
